Based on the NCI ODWG criteria with TB the total (direct and indirect) serum bilirubin, and AST aspartate aminotransferase.
Usage
add_bl_odwg(
obj,
sdtm,
observation_filter = NULL,
baseline_filter = NULL,
summary_function = mean,
silent = NULL
)Arguments
- obj
A nif object.
- sdtm
The corresponding sdtm object.
- observation_filter
The filter term for the observation source data, as character.
- baseline_filter
A filter term to identify the baseline condition, as character.
- summary_function
The summary function to summarize multiple baseline values. Defaults to
mean- silent
Suppress messages.