Set global behavior options for all nif package functions. Currently
supported:
silentas logical: Suppress messages.watermarkas character: Watermark text on all figures.pinboardas character: Pinboard path for sharing of nif/sdtm objects.debugas logical: Print debug information.show_hashas logical: Include dataset hash in figures.abbreviation_thresholdas numeric: Allowed line count in message output without abbreviation. Set to Inf to always show all lines.abbreviation_maxlinesas numeric: Line number to that lists in message output will be abbreviated if the line count threshold is exceeded.